<?php
use MASCOTCOREROFOT\CPT\Portfolio\CPT_Portfolio;

/*
 * Adds Mascot_Core_Rofot_Widget_Portfolio widget.
 */
if( !class_exists( 'Mascot_Core_Rofot_Widget_Portfolio' ) ) {
class Mascot_Core_Rofot_Widget_Portfolio extends Mascot_Core_Rofot_Widget_Loader {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		$this->widgetOptions = array( 
			'classname'		=> 'widget-portfolio clearfix',
			'description'	=> esc_html__( 'The widget lets you easily display Portfolio as grid or carousel.', 'mascot-core' ),
		);
		parent::__construct( 'tm_widget_portfolio', esc_html__( '(TM) Portfolio', 'mascot-core' ), $this->widgetOptions );
		$this->getFormFields();
	}

	
	/**
	 * Get form fields of the widget.
	 */
	protected function getFormFields() {
		$new_cpt_class = CPT_Portfolio::Instance();
		$categories_array = mascot_core_rofot_category_list_array( $new_cpt_class->ptTaxKey );
		$orderby_parameters_list = mascot_core_rofot_orderby_parameters_list();
		$this->formFields = array(
			array(
				'id'		=> 'title',
				'type'		=> 'text',
				'title'		=> esc_html__( 'Widget Title:', 'mascot-core' ),
				'desc'		=> '',
				'default'	=> esc_html__( 'Portfolio', 'mascot-core' ),
			),
			array(
				'id'		=> 'custom_css_class',
				'type'		=> 'text',
				'title'		=> esc_html__( 'Custom CSS Class:', 'mascot-core' ),
				'desc'		=> esc_html__( 'To style particular content element', 'mascot-core' ),
			),
			array(
				'id'		=> 'portfolio_category',				
				'type'		=> 'text',
				'title'		=> esc_html__( 'Portfolio Category', 'mascot-core' ),
				'desc'		=> '',
			),
			array(
				'id'		=> 'order_by',
				'type'		=> 'dropdown',
				'title'		=> esc_html__( 'Order By:', 'mascot-core' ),
				'desc'		=> '',
				'options'	=> array(
					'date'			=> esc_html__( 'Date', 'mascot-core' ),
					'title'		=> esc_html__( 'Title', 'mascot-core' ),
					'comment_count' => esc_html__( 'Number of Comments', 'mascot-core' )
				)
			),
			array(
				'id'		=> 'order',				
				'type'		=> 'dropdown',
				'title'		=> esc_html__( 'Order:', 'mascot-core' ),
				'desc'		=> '',
				'options'	=> array(
					'DESC' => esc_html__( 'DESC', 'mascot-core' ),
					'ASC'  => esc_html__( 'ASC', 'mascot-core' )
				)
			),
			array(
				'id'		=> 'items_count',
				'type'		=> 'text',
				'title'		=> esc_html__( 'Number of Items to Show', 'mascot-core' ),
				'desc'		=> '',
			),
			array(
				'id'		=> 'type',
				'type'		=> 'dropdown',
				'title'		=> esc_html__( 'Portfolio Type:', 'mascot-core' ),
				'desc'		=> '',
				'options'	=> array(
					'grid'		=> esc_html__( 'Grid', 'mascot-core' ),
					'carousel'   => esc_html__( 'Carousel', 'mascot-core' ),
				)
			),
		);
	}



	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args	 Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {

		echo wp_kses_post($args['before_widget']);

		if ( ! empty( $instance['title'] ) ) {
			echo wp_kses_post( $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'] );
		}

		//get gallery instance
		$new_cpt_class = CPT_Portfolio::Instance();
		//default posts per page
		$posts_per_page = ( $instance['items_count'] == '' ) ? -1 : $instance['items_count'];
		//query args
		$query_args = array(
			'post_type' => $new_cpt_class->ptKey,
			'orderby' => $instance['order_by'],
			'order' => $instance['order'],
			'posts_per_page' => $posts_per_page,
		);

		//if category selected
		if( ! empty( $instance['portfolio_category'] ) ) {
			$query_args['tax_query'] = array(
				array(
					'taxonomy' => $new_cpt_class->ptTaxKey,
					'field'	=> 'slug',
					'terms'	=> explode(',', $instance['portfolio_category']),
				)
			);
		}

		$the_query = new \WP_Query( $query_args );
		$instance['the_query'] = $the_query;

		//ptTaxKey
		$instance['ptTaxKey'] = $new_cpt_class->ptTaxKey;

		//Produce HTML version by using the parameters (filename, variation, folder name, parameters, widget_ob_start)
		$html = mascot_core_rofot_get_widget_template_part( 'portfolio' . '-' . $instance['type'], null, 'portfolio/tpl', $instance, false );

		echo wp_kses_post($args['after_widget']);

	}
}
}